unit GWVisio_Demo_01_Main;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, GWVisio_Controller, ExtCtrls;

type
  Tfm_Main = class(TForm)
    GroupBox1: TGroupBox;
    bt_VisioConnect: TButton;
    lb_Test: TLabel;
    bt_Disconnect: TButton;
    bt_VisioVersion: TButton;
    GroupBox2: TGroupBox;
    StaticText1: TStaticText;
    bt_Left: TButton;
    bt_Right: TButton;
    GroupBox3: TGroupBox;
    bt_EventInit: TButton;
    bt_RegEvent: TButton;
    Label1: TLabel;
    Label2: TLabel;
    bt_DisconnectEvents: TButton;
    Label3: TLabel;
    GroupBox4: TGroupBox;
    Panel1: TPanel;
    mm_Events: TMemo;
    bt_EventsClear: TButton;
    Label4: TLabel;
    bt_TestEvent: TButton;
    Label5: TLabel;
    bt_UnRegister: TButton;
    Label6: TLabel;
    Panel2: TPanel;
    Label7: TLabel;
    Label8: TLabel;
    procedure bt_VisioConnectClick(Sender: TObject);
    procedure bt_RegEventClick(Sender: TObject);
    procedure bt_EventInitClick(Sender: TObject);
    procedure bt_TestEventClick(Sender: TObject);
    procedure bt_MoveClick(Sender: TObject);
    procedure bt_EventsClearClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure bt_DisconnectClick(Sender: TObject);
    procedure bt_VisioVersionClick(Sender: TObject);
    procedure bt_DisconnectEventsClick(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure bt_UnRegisterClick(Sender: TObject);
  private
    { Private declarations }
    function MyVisioCallback(AGWVisio_EventInfo: TGWVisio_EventInfo): HResult;
  public
    { Public declarations }
    ShapeDelEventIndex: integer;
    CellModEventIndex:  integer;
  end;

var
  fm_Main: Tfm_Main;

//-------------------------------------------------------
   implementation
//-------------------------------------------------------
uses Visio_TLB;

{$R *.DFM}
//***********************************************************
// Basic Visio Connect/Disconnect
//***********************************************************

//-------------------------------------------------------
procedure Tfm_Main.bt_VisioConnectClick(Sender: TObject);
//-------------------------------------------------------
begin
  Visio_Controller.Connect(tvco_TryExisting);
  bt_VisioVersionClick(nil)
end;

//-------------------------------------------------------
procedure Tfm_Main.bt_DisconnectClick(Sender: TObject);
//-------------------------------------------------------
begin
  Visio_Controller.Disconnect;
  lb_Test.Caption := 'Disconnected';
end;

//-------------------------------------------------------
procedure Tfm_Main.bt_VisioVersionClick(Sender: TObject);
//-------------------------------------------------------
begin
  try
    lb_Test.Caption := 'Version ' + Visio_Controller.Application.Version;
  except
    on E: Exception do
      lb_Test.Caption := E.Message;
  end;
end;

//*******************************************************
// Demo Automation properties and a function
//*******************************************************

//-------------------------------------------------------
procedure Tfm_Main.bt_MoveClick(Sender: TObject);
//-------------------------------------------------------
Var
  Sel:    IVSelection;
  IUnk:   IUnknown;
  Cell:   IVCell;
  S:      string;
  R:      single;
  E:      integer;
begin
  Sel := Visio_Controller.Application.ActiveWindow.Selection;

  If Sel.Count = 1 then
  Begin

    IUnk := Sel.Item[1];
    try
      Cell := (IUnk as IVShape).Cells['PinX'];
      R := Cell.Result_['in'];

      if Sender = bt_Left then R := R - 0.1 else R := R + 0.1;
      Cell.Result_['in']  := R;
    except

    end;
  end else
  Begin
    ShowMessage('Please select exactly one shape in Visio');
  end;
end;

//****************************************************************
// Events-related stuff
//****************************************************************

//----------------------------------------------------------------
// This is the function that we supply for to get called back when
// Visio reports an event.
//----------------------------------------------------------------

//-------------------------------------------------------
function Tfm_Main.MyVisioCallback(AGWVisio_EventInfo: TGWVisio_EventInfo): HResult;
//-------------------------------------------------------

Var
  S, S1: string;
Begin
  S := '';

  If Assigned(AGWVisio_EventInfo) then
  Begin
    S1 := IntToHex(AGWVisio_EventInfo.Event,4);
    S := S + S1;

    S1 := IntToHex(AGWVisio_EventInfo.ID,8);
    S := S + ' ' + S1;

    S1 := IntToHex(AGWVisio_EventInfo.Seq,8);
    S := S + ' ' + S1;

    try
      S1 := (AGWVisio_EventInfo.Subject as IVShape).Name;
      S := S + ' ' + S1;
    except
    end;

    S := S + ' <' + AGWVisio_EventInfo.Extra +'>';
  end else
  Begin
    S := 'Callback received no event info';
  end;

  fm_Main.mm_Events.Lines.Add(S);

  Result := NOERROR;
end;

//-------------------------------------------------------
procedure Tfm_Main.bt_EventInitClick(Sender: TObject);
//-------------------------------------------------------
Var
  hr: HResult;
begin
  hr := Visio_Controller.EventHandling_Init(MyVisioCallback);
end;

//-------------------------------------------------------
procedure Tfm_Main.bt_TestEventClick(Sender: TObject);
//-------------------------------------------------------
begin
  Visio_Controller.TestOnVisEvent;
end;

//-------------------------------------------------------
// The following registers us for a couple of events --
// Modify Cell and Shape Delete
// both at the Application level
//-------------------------------------------------------

//-------------------------------------------------------
procedure Tfm_Main.bt_RegEventClick(Sender: TObject);
//-------------------------------------------------------
begin
  if ShapeDelEventIndex = -1 then
    ShapeDelEventIndex := Visio_Controller.RegisterForEvent(
             Visio_Controller.Application,   //  WatchObject  : OleVariant;
             visEvtShape or visEvtDel,       //  AEvtxxx      : longword;
             'Shape Del'                     //  targetArgs
             ); // : IVEvent;

  if CellModEventIndex = -1 then
    CellModEventIndex := Visio_Controller.RegisterForEvent(
             Visio_Controller.Application,   // WatchObject  : OleVariant;
             visEvtMod+visEvtCell,           //  AEvtxxx      : longword;
             'Cell Mod'                      // targetArgs
             ); // : IVEvent;
end;

//-------------------------------------------------------
procedure Tfm_Main.bt_UnRegisterClick(Sender: TObject);
//-------------------------------------------------------
begin
  if ShapeDelEventIndex <> -1 then
  Begin
    Visio_Controller.UnregisterEvent(ShapeDelEventIndex);
    ShapeDelEventIndex := -1;
  end;
  if CellModEventIndex <> -1 then
  Begin
    Visio_Controller.UnRegisterEvent(CellModEventIndex);
    CellModEventIndex := -1;
  end;
end;

//---------------------------------------------
procedure Tfm_Main.bt_DisconnectEventsClick(Sender: TObject);
//---------------------------------------------
begin
  Visio_Controller.EventHandling_Disconnect;
  ShapeDelEventIndex := -1;
  CellModEventIndex  := -1;
end;

//---------------------------------------------
procedure Tfm_Main.bt_EventsClearClick(Sender: TObject);
//---------------------------------------------
begin
  mm_Events.Lines.Clear;
end;

//*********************************************
// Form housekeeping
//*********************************************
//---------------------------------------------
procedure Tfm_Main.FormCreate(Sender: TObject);
//---------------------------------------------
begin
  Top   := 100;
  Left  := 100;
  Width := 480;
  ShapeDelEventIndex := -1;
  CellModEventIndex  := -1;
end;

//---------------------------------------------
procedure Tfm_Main.FormClose(Sender: TObject; var Action: TCloseAction);
//---------------------------------------------
begin
  Visio_Controller.Disconnect;
end;




end.

